==> dustpy-0.5.2.tar.gz: dustpy-0.5.2/README.md <==
# DustPy

Package for Dust Coagulation and Evolution in Protoplanetary Disks.

## Terms of Usage

Usage is only permitted under the condition of close collaboration and the option of co-authorship to publications that made use of `DustPy`, until the code paper is published.  
By using any version of `DustPy` you agree to these terms of usage.

## Installation

`pip install dustpy`

## Documentation

[https://stammler.github.io/dustpy/](https://stammler.github.io/dustpy/)


* [1. Basics](https://stammler.github.io/dustpy/1_basics.html)
* [2. Simple Customization](https://stammler.github.io/dustpy/2_simple_customization.html)
* [3. Advanced Customization](https://stammler.github.io/dustpy/3_advanced_customization.html)
* [4. The Standard Model](https://stammler.github.io/dustpy/4_standard_model.html)
* [5. Dust Coagulation](https://stammler.github.io/dustpy/5_dust_coagulation.html)
* [6. Dust Evolution](https://stammler.github.io/dustpy/6_dust_evolution.html)
* [7. Gas Evolution](https://stammler.github.io/dustpy/7_gas_evolution.html)
* [8. Test: Gas Evolution](https://stammler.github.io/dustpy/8_test_gas_evolution.html)
* [9. Example: Planetary Gaps](https://stammler.github.io/dustpy/9_example_gaps.html)
* [10. Example: Ice Lines](https://stammler.github.io/dustpy/10_example_ice_lines.html)
* [11. Example: Planetesimal Formation](https://stammler.github.io/dustpy/11_example_planetesimal_formation.html)

[Module Reference](https://stammler.github.io/dustpy/api.html)

`DustPy` is using the `simframe` framework.  
For details we refer to the [Simframe Documentation](https://simframe.rtfd.io/).

## Ackowledgements

`DustPy` has received funding from the European Research Council (ERC) under the European Union’s Horizon 2020 research and innovation programme under grant agreement No 714769.

`DustPy` was developed at the [University Observatory](https://www.usm.uni-muenchen.de/index_en.php) of the [Ludwig Maximilian University of Munich](https://www.en.uni-muenchen.de/index.html).

==> dustpy-0.5.8.tar.gz: dustpy-0.5.8/README.md <==
# DustPy

Package for Dust Coagulation and Evolution in Protoplanetary Disks.

## Terms of Usage

Usage is only permitted under the condition of close collaboration and the option of co-authorship to publications that made use of `DustPy`, until the code paper is published.  
By using any version of `DustPy` you agree to these terms of usage.

## Installation

`pip install dustpy`

## Documentation

[https://stammler.github.io/dustpy/](https://stammler.github.io/dustpy/)

* [1. Basics](https://stammler.github.io/dustpy/1_basics.html)
* [2. Simple Customization](https://stammler.github.io/dustpy/2_simple_customization.html)
* [3. Advanced Customization](https://stammler.github.io/dustpy/3_advanced_customization.html)
* [4. The Standard Model](https://stammler.github.io/dustpy/4_standard_model.html)
* [5. Dust Coagulation](https://stammler.github.io/dustpy/5_dust_coagulation.html)
* [6. Dust Evolution](https://stammler.github.io/dustpy/6_dust_evolution.html)
* [7. Gas Evolution](https://stammler.github.io/dustpy/7_gas_evolution.html)

* [Test: Analytical Coagulation Kernels](https://stammler.github.io/dustpy/test_analytical_coagulation_kernels.html)
* [Test: Gas Evolution](https://stammler.github.io/dustpy/test_gas_evolution.html)

* [Example: Ice Lines](https://stammler.github.io/dustpy/example_ice_lines.html)
* [Example: Planetary Gaps](https://stammler.github.io/dustpy/example_planetary_gaps.html)
* [Example: Planetesimal Formation](https://stammler.github.io/dustpy/example_planetesimal_formation.html)

[Module Reference](https://stammler.github.io/dustpy/api.html)

`DustPy` is using the `simframe` framework.  
For details we refer to the [Simframe Documentation](https://simframe.rtfd.io/).

## Ackowledgements

`DustPy` has received funding from the European Research Council (ERC) under the European Union’s Horizon 2020 research and innovation programme under grant agreement No 714769.

`DustPy` was developed at the [University Observatory](https://www.usm.uni-muenchen.de/index_en.php) of the [Ludwig Maximilian University of Munich](https://www.en.uni-muenchen.de/index.html).
